@@ -4,7 +4,7 @@
 //  Handlers for events relating to the display of a survey.
 //
 //  Copyright (C) 2000-2002,2005 Mark R. Shinwell
-//  Copyright (C) 2001,2003,2004,2005,2006 Olly Betts
+//  Copyright (C) 2001,2003,2004,2005,2006,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -41,11 +41,6 @@ GUIControl::GUIControl()
     m_LastDrag = drag_NONE;
 }
 
-GUIControl::~GUIControl()
-{
-    // no action
-}
-
 void GUIControl::SetView(GfxCore* view)
 {
     m_View = view;
@@ -67,7 +62,7 @@ void GUIControl::HandleTilt(wxPoint point)
 
     if (m_ReverseControls != m_View->GetPerspective()) dy = -dy;
 
-    m_View->TiltCave(Double(-dy) * 0.36);
+    m_View->TiltCave(Double(dy) * 0.36);
 
     m_DragStart = point;
 
@@ -187,7 +182,7 @@ void GUIControl::HandleTiltRotate(wxPoint point)
     // left/right => rotate, up/down => tilt.
     // Make tilt less sensitive than rotate as that feels better.
     m_View->TurnCave(Double(dx) * -0.36);
-    m_View->TiltCave(Double(dy) * -0.18);
+    m_View->TiltCave(Double(dy) * 0.18);
 
     m_View->ForceRefresh();
 
@@ -400,6 +395,9 @@ void GUIControl::OnMButtonUp(wxMouseEvent&)
 void GUIControl::OnRButtonDown(wxMouseEvent& event)
 {
     if (m_View->HasData()) {
+	if (m_View->HandleRClick(event.GetPosition()))
+	    return;
+
 	m_DragStart = event.GetPosition();
 
 	dragging = RIGHT_DRAG;
@@ -471,19 +469,19 @@ void GUIControl::OnColourByError()
 
 void GUIControl::OnColourByDepthUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData() && !m_View->HasDepth());
+    cmd.Enable(m_View->HasData());
     cmd.Check(m_View->ColouringBy() == COLOUR_BY_DEPTH);
 }
 
 void GUIControl::OnColourByDateUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData() && m_View->HasUndergroundLegs() && m_View->HasRangeOfDates());
+    cmd.Enable(m_View->HasData());
     cmd.Check(m_View->ColouringBy() == COLOUR_BY_DATE);
 }
 
 void GUIControl::OnColourByErrorUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData() && m_View->HasUndergroundLegs() && m_View->HasErrorInformation());
+    cmd.Enable(m_View->HasData());
     cmd.Check(m_View->ColouringBy() == COLOUR_BY_ERROR);
 }
 
@@ -528,7 +526,7 @@ void GUIControl::OnMoveEast()
 
 void GUIControl::OnMoveEastUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData() && !m_View->IsExtendedElevation());
+    cmd.Enable(m_View->HasData() && !m_View->IsExtendedElevation() && m_View->GetCompassValue() != 90.0);
 }
 
 void GUIControl::OnMoveNorth()
@@ -539,7 +537,7 @@ void GUIControl::OnMoveNorth()
 
 void GUIControl::OnMoveNorthUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData());
+    cmd.Enable(m_View->HasData() && m_View->GetCompassValue() != 0.0);
 }
 
 void GUIControl::OnMoveSouth()
@@ -550,7 +548,7 @@ void GUIControl::OnMoveSouth()
 
 void GUIControl::OnMoveSouthUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData());
+    cmd.Enable(m_View->HasData() && m_View->GetCompassValue() != 180.0);
 }
 
 void GUIControl::OnMoveWest()
@@ -561,7 +559,7 @@ void GUIControl::OnMoveWest()
 
 void GUIControl::OnMoveWestUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData() && !m_View->IsExtendedElevation());
+    cmd.Enable(m_View->HasData() && !m_View->IsExtendedElevation() && m_View->GetCompassValue() != 270.0);
 }
 
 void GUIControl::OnToggleRotation()
@@ -672,9 +670,9 @@ void GUIControl::OnHigherViewpoint(bool accel)
 {
     // Raise the viewpoint.
     if (m_View->GetPerspective()) {
-	m_View->TiltCave(accel ? -5.0 * ROTATE_STEP : -ROTATE_STEP);
-    } else {
 	m_View->TiltCave(accel ? 5.0 * ROTATE_STEP : ROTATE_STEP);
+    } else {
+	m_View->TiltCave(accel ? -5.0 * ROTATE_STEP : -ROTATE_STEP);
     }
     m_View->ForceRefresh();
 }
@@ -688,9 +686,9 @@ void GUIControl::OnLowerViewpoint(bool accel)
 {
     // Lower the viewpoint.
     if (m_View->GetPerspective()) {
-	m_View->TiltCave(accel ? 5.0 * ROTATE_STEP : ROTATE_STEP);
-    } else {
 	m_View->TiltCave(accel ? -5.0 * ROTATE_STEP : -ROTATE_STEP);
+    } else {
+	m_View->TiltCave(accel ? 5.0 * ROTATE_STEP : ROTATE_STEP);
     }
     m_View->ForceRefresh();
 }
@@ -808,15 +806,15 @@ void GUIControl::OnToggleScalebarUpdate(wxUpdateUIEvent& cmd)
     cmd.Check(m_View->ShowingScaleBar());
 }
 
-void GUIControl::OnToggleDepthbar() /* FIXME naming */
+void GUIControl::OnToggleColourKey()
 {
-    m_View->ToggleDepthBar();
+    m_View->ToggleColourKey();
 }
 
-void GUIControl::OnToggleDepthbarUpdate(wxUpdateUIEvent& cmd)
+void GUIControl::OnToggleColourKeyUpdate(wxUpdateUIEvent& cmd)
 {
-    cmd.Enable(m_View->HasData() && m_View->ColouringBy() == COLOUR_BY_DEPTH);
-    cmd.Check(m_View->ShowingDepthBar());
+    cmd.Enable(m_View->HasData() && m_View->ColouringBy() != COLOUR_BY_NONE);
+    cmd.Check(m_View->ShowingColourKey());
 }
 
 void GUIControl::OnViewCompass()
@@ -1023,28 +1021,28 @@ void GUIControl::OnKeyPress(wxKeyEvent &e)
     // on windows?)  FIXME : check!
     //bool refresh = m_View->Animate();
 
-    switch (e.m_keyCode) {
+    switch (e.GetKeyCode()) {
 	case '/': case '?':
 	    if (m_View->CanLowerViewpoint() && !m_View->IsExtendedElevation())
-		OnLowerViewpoint(e.m_shiftDown);
+		OnLowerViewpoint(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case '\'': case '@': case '"': // both shifted forms - US and UK kbd
 	    if (m_View->CanRaiseViewpoint() && !m_View->IsExtendedElevation())
-		OnHigherViewpoint(e.m_shiftDown);
+		OnHigherViewpoint(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case 'C': case 'c':
 	    if (!m_View->IsExtendedElevation() && !m_View->IsRotating())
-		OnStepOnceAnticlockwise(e.m_shiftDown);
+		OnStepOnceAnticlockwise(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case 'V': case 'v':
 	    if (!m_View->IsExtendedElevation() && !m_View->IsRotating())
-		OnStepOnceClockwise(e.m_shiftDown);
+		OnStepOnceClockwise(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case ']': case '}':
-	    OnZoomIn(e.m_shiftDown);
+	    OnZoomIn(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case '[': case '{':
-	    OnZoomOut(e.m_shiftDown);
+	    OnZoomOut(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case 'N': case 'n':
 	    OnMoveNorth();
@@ -1062,11 +1060,11 @@ void GUIControl::OnKeyPress(wxKeyEvent &e)
 	    break;
 	case 'Z': case 'z':
 	    if (!m_View->IsExtendedElevation())
-		OnSpeedUp(e.m_shiftDown);
+		OnSpeedUp(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case 'X': case 'x':
 	    if (!m_View->IsExtendedElevation())
-		OnSlowDown(e.m_shiftDown);
+		OnSlowDown(e.GetModifiers() == wxMOD_SHIFT);
 	    break;
 	case 'R': case 'r':
 	    if (!m_View->IsExtendedElevation())
@@ -1096,35 +1094,35 @@ void GUIControl::OnKeyPress(wxKeyEvent &e)
 		OnToggleRotation();
 	    break;
 	case WXK_LEFT:
-	    if (e.m_controlDown) {
+	    if ((e.GetModifiers() &~ wxMOD_SHIFT) == wxMOD_CONTROL) {
 		if (!m_View->IsExtendedElevation() && !m_View->IsRotating())
-		    OnStepOnceAnticlockwise(e.m_shiftDown);
+		    OnStepOnceAnticlockwise(e.GetModifiers() == wxMOD_SHIFT);
 	    } else {
-		OnShiftDisplayLeft(e.m_shiftDown);
+		OnShiftDisplayLeft(e.GetModifiers() == wxMOD_SHIFT);
 	    }
 	    break;
 	case WXK_RIGHT:
-	    if (e.m_controlDown) {
+	    if ((e.GetModifiers() &~ wxMOD_SHIFT) == wxMOD_CONTROL) {
 		if (!m_View->IsExtendedElevation() && !m_View->IsRotating())
-		    OnStepOnceClockwise(e.m_shiftDown);
+		    OnStepOnceClockwise(e.GetModifiers() == wxMOD_SHIFT);
 	    } else {
-		OnShiftDisplayRight(e.m_shiftDown);
+		OnShiftDisplayRight(e.GetModifiers() == wxMOD_SHIFT);
 	    }
 	    break;
 	case WXK_UP:
-	    if (e.m_controlDown) {
+	    if ((e.GetModifiers() &~ wxMOD_SHIFT) == wxMOD_CONTROL) {
 		if (m_View->CanRaiseViewpoint() && !m_View->IsExtendedElevation())
-		    OnHigherViewpoint(e.m_shiftDown);
+		    OnHigherViewpoint(e.GetModifiers() == wxMOD_SHIFT);
 	    } else {
-		OnShiftDisplayUp(e.m_shiftDown);
+		OnShiftDisplayUp(e.GetModifiers() == wxMOD_SHIFT);
 	    }
 	    break;
 	case WXK_DOWN:
-	    if (e.m_controlDown) {
+	    if ((e.GetModifiers() &~ wxMOD_SHIFT) == wxMOD_CONTROL) {
 		if (m_View->CanLowerViewpoint() && !m_View->IsExtendedElevation())
-		    OnLowerViewpoint(e.m_shiftDown);
+		    OnLowerViewpoint(e.GetModifiers() == wxMOD_SHIFT);
 	    } else {
-		OnShiftDisplayDown(e.m_shiftDown);
+		OnShiftDisplayDown(e.GetModifiers() == wxMOD_SHIFT);
 	    }
 	    break;
 	case WXK_ESCAPE:
@@ -1132,6 +1130,20 @@ void GUIControl::OnKeyPress(wxKeyEvent &e)
 		OnCancelDistLine();
 	    }
 	    break;
+	case WXK_F5:
+	    m_View->InvalidateAllLists();
+	    m_View->ForceRefresh();
+	    break;
+#ifdef __WXMAC__
+	// Hugh St Lawrence reports that F11 enters full screen mode, but that
+	// there's no easy way back out (you have to exit aven and then edit
+	// "user(name)/Library/Preferences/aven Preferences" to remove the
+	// "width=-2" setting.  So we process this key press explicitly to
+	// fix this.  He was using the pre-built Survex 1.2.0 and OS X 10.6.8.
+	case WXK_F11:
+	    OnViewFullScreen();
+	    break;
+#endif
 	default:
 	    e.Skip();
     }
