@@ -56,7 +56,6 @@ class GUIControl {
 
 public:
     GUIControl();
-    ~GUIControl();
 
     void SetView(GfxCore* view);
 
@@ -92,7 +91,7 @@ public:
     void OnZoomIn(bool accel = false);
     void OnZoomOut(bool accel = false);
     void OnToggleScalebar();
-    void OnToggleDepthbar();
+    void OnToggleColourKey();
     void OnViewCompass();
     void OnViewClino();
     void OnViewGrid();
@@ -142,7 +141,7 @@ public:
     void OnZoomInUpdate(wxUpdateUIEvent&);
     void OnZoomOutUpdate(wxUpdateUIEvent&);
     void OnToggleScalebarUpdate(wxUpdateUIEvent&);
-    void OnToggleDepthbarUpdate(wxUpdateUIEvent&);
+    void OnToggleColourKeyUpdate(wxUpdateUIEvent&);
     void OnViewCompassUpdate(wxUpdateUIEvent&);
     void OnViewClinoUpdate(wxUpdateUIEvent&);
     void OnViewGridUpdate(wxUpdateUIEvent&);
