@@ -14,9 +14,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 int hash_string(const char *p);
 int hash_lc_string(const char *p);
 int hash_data(const char *p, size_t len);
+
+#ifdef __cplusplus
+}
+#endif
