@@ -4,7 +4,7 @@
 //  Main frame handling for Aven.
 //
 //  Copyright (C) 2000-2002,2005,2006 Mark R. Shinwell
-//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011 Olly Betts
+//  Copyright (C) 2001-2003,2004,2005,2006,2010,2011,2012 Olly Betts
 //  Copyright (C) 2005 Martin Green
 //
 //  This program is free software; you can redistribute it and/or modify
@@ -33,7 +33,7 @@
 
 #include "message.h"
 #include "img.h"
-#include "namecmp.h"
+#include "namecompare.h"
 #include "printwx.h"
 #include "filename.h"
 #include "useful.h"
@@ -319,7 +319,7 @@ class AvenPresList : public wxListCtrl {
 	    FILE * fh_pres = fopen(fnm.mb_str(), "w");
 #endif
 	    if (!fh_pres) {
-		wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file `%s'*/110), fnm.c_str()));
+		wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/110), fnm.c_str()));
 		return;
 	    }
 	    vector<PresentationMark>::const_iterator i;
@@ -361,7 +361,7 @@ class AvenPresList : public wxListCtrl {
 #endif
 	    if (!fh_pres) {
 		wxString m;
-		m.Printf(wmsg(/*Couldn't open file `%s'*/93), fnm.c_str());
+		m.Printf(wmsg(/*Couldn’t open file “%s”*/93), fnm.c_str());
 		wxGetApp().ReportError(m);
 		return false;
 	    }
@@ -385,7 +385,7 @@ class AvenPresList : public wxListCtrl {
 			c = sscanf(buf, "%lf %lf %lf %lf %lf %lf %lf", &x, &y, &z, &a, &t, &s, &T);
 			if (c < 6) {
 			    DeleteAllItems();
-			    wxGetApp().ReportError(wxString::Format(wmsg(/*Error in format of presentation file `%s'*/323), fnm.c_str()));
+			    wxGetApp().ReportError(wxString::Format(wmsg(/*Error in format of presentation file “%s”*/323), fnm.c_str()));
 			    return false;
 			}
 		    }
@@ -603,18 +603,18 @@ BEGIN_EVENT_TABLE(MainFrm, wxFrame)
 END_EVENT_TABLE()
 
 class LabelCmp : public greater<const LabelInfo*> {
-    int separator;
+    wxChar separator;
 public:
-    LabelCmp(int separator_) : separator(separator_) {}
+    LabelCmp(wxChar separator_) : separator(separator_) {}
     bool operator()(const LabelInfo* pt1, const LabelInfo* pt2) {
 	return name_cmp(pt1->GetText(), pt2->GetText(), separator) < 0;
     }
 };
 
 class LabelPlotCmp : public greater<const LabelInfo*> {
-    int separator;
+    wxChar separator;
 public:
-    LabelPlotCmp(int separator_) : separator(separator_) {}
+    LabelPlotCmp(wxChar separator_) : separator(separator_) {}
     bool operator()(const LabelInfo* pt1, const LabelInfo* pt2) {
 	int n = pt1->get_flags() - pt2->get_flags();
 	if (n) return n > 0;
@@ -709,14 +709,14 @@ void MainFrm::CreateMenuBar()
 
     wxMenu* filemenu = new wxMenu;
     // wxID_OPEN stock label lacks the ellipses
-    filemenu->Append(wxID_OPEN, wmsg(/*&Open...\tCtrl+O*/220));
+    filemenu->Append(wxID_OPEN, wmsg(/*&Open…\tCtrl+O*/220));
     filemenu->AppendSeparator();
     // wxID_PRINT stock label lacks the ellipses
-    filemenu->Append(wxID_PRINT, wmsg(/*&Print...\tCtrl+P*/380));
-    filemenu->Append(menu_FILE_PAGE_SETUP, wmsg(/*P&age Setup...*/381));
+    filemenu->Append(wxID_PRINT, wmsg(/*&Print…\tCtrl+P*/380));
+    filemenu->Append(menu_FILE_PAGE_SETUP, wmsg(/*P&age Setup…*/381));
     filemenu->AppendSeparator();
-    filemenu->Append(menu_FILE_SCREENSHOT, wmsg(/*&Screenshot...*/201));
-    filemenu->Append(menu_FILE_EXPORT, wmsg(/*&Export as...*/382));
+    filemenu->Append(menu_FILE_SCREENSHOT, wmsg(/*&Screenshot…*/201));
+    filemenu->Append(menu_FILE_EXPORT, wmsg(/*&Export as…*/382));
 #ifndef __WXMAC__
     // On wxMac the "Quit" menu item will be moved elsewhere, so we suppress
     // this separator.
@@ -728,7 +728,7 @@ void MainFrm::CreateMenuBar()
     m_history.Load(*wxConfigBase::Get());
 
     wxMenu* rotmenu = new wxMenu;
-    rotmenu->AppendCheckItem(menu_ROTATION_TOGGLE, wmsg(/*&Auto-Rotate\tSpace*/231));
+    rotmenu->AppendCheckItem(menu_ROTATION_TOGGLE, wmsg(/*Au&to-Rotate\tSpace*/231));
     rotmenu->AppendSeparator();
     rotmenu->Append(menu_ROTATION_SPEED_UP, wmsg(/*Speed &Up*/232));
     rotmenu->Append(menu_ROTATION_SLOW_DOWN, wmsg(/*Slow &Down*/233));
@@ -763,18 +763,18 @@ void MainFrm::CreateMenuBar()
 
     wxMenu* presmenu = new wxMenu;
     presmenu->Append(menu_PRES_NEW, wmsg(/*&New Presentation*/311));
-    presmenu->Append(menu_PRES_OPEN, wmsg(/*&Open Presentation...*/312));
+    presmenu->Append(menu_PRES_OPEN, wmsg(/*&Open Presentation…*/312));
     presmenu->Append(menu_PRES_SAVE, wmsg(/*&Save Presentation*/313));
-    presmenu->Append(menu_PRES_SAVE_AS, wmsg(/*Save Presentation &As...*/314));
+    presmenu->Append(menu_PRES_SAVE_AS, wmsg(/*Sa&ve Presentation As…*/314));
     presmenu->AppendSeparator();
     presmenu->Append(menu_PRES_MARK, wmsg(/*&Mark*/315));
-    presmenu->Append(menu_PRES_PLAY, wmsg(/*&Play*/316));
-    presmenu->Append(menu_PRES_EXPORT_MOVIE, wmsg(/*&Export as Movie...*/317));
+    presmenu->Append(menu_PRES_PLAY, wmsg(/*Pla&y*/316));
+    presmenu->Append(menu_PRES_EXPORT_MOVIE, wmsg(/*&Export as Movie…*/317));
 
     wxMenu* viewmenu = new wxMenu;
 #ifndef PREFDLG
     viewmenu->AppendCheckItem(menu_VIEW_SHOW_NAMES, wmsg(/*Station &Names\tCtrl+N*/270));
-    viewmenu->AppendCheckItem(menu_VIEW_SHOW_TUBES, wmsg(/*Passage &Tubes*/346));
+    viewmenu->AppendCheckItem(menu_VIEW_SHOW_TUBES, wmsg(/*Passage &Tubes\tCtrl+T*/346));
     viewmenu->AppendCheckItem(menu_VIEW_SHOW_CROSSES, wmsg(/*&Crosses\tCtrl+X*/271));
     viewmenu->AppendCheckItem(menu_VIEW_GRID, wmsg(/*&Grid\tCtrl+G*/297));
     viewmenu->AppendCheckItem(menu_VIEW_BOUNDING_BOX, wmsg(/*&Bounding Box\tCtrl+B*/318));
@@ -797,13 +797,13 @@ void MainFrm::CreateMenuBar()
     viewmenu->AppendCheckItem(menu_VIEW_PERSPECTIVE, wmsg(/*&Perspective*/237));
 // FIXME: enable this    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_SHADING, wmsg(/*&Smooth Shading*/?!?);
     viewmenu->AppendCheckItem(menu_VIEW_TEXTURED, wmsg(/*Textured &Walls*/238));
-    viewmenu->AppendCheckItem(menu_VIEW_FOG, wmsg(/*Fade &Distant Objects*/239));
-    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_LINES, wmsg(/*&Smoothed Survey Legs*/298));
+    viewmenu->AppendCheckItem(menu_VIEW_FOG, wmsg(/*Fade Distant Ob&jects*/239));
+    viewmenu->AppendCheckItem(menu_VIEW_SMOOTH_LINES, wmsg(/*Smoot&hed Survey Legs*/298));
     viewmenu->AppendSeparator();
-    viewmenu->AppendCheckItem(menu_VIEW_FULLSCREEN, wmsg(/*&Full Screen Mode\tF11*/356));
+    viewmenu->AppendCheckItem(menu_VIEW_FULLSCREEN, wmsg(/*Full Screen &Mode\tF11*/356));
 #ifdef PREFDLG
     viewmenu->AppendSeparator();
-    viewmenu-> Append(wxID_PREFERENCES, wmsg(/*&Preferences...*/347));
+    viewmenu-> Append(wxID_PREFERENCES, wmsg(/*&Preferences…*/347));
 #endif
 
 #ifndef PREFDLG
@@ -824,9 +824,6 @@ void MainFrm::CreateMenuBar()
     ctlmenu->AppendCheckItem(menu_CTL_DEGREES, wmsg(/*&Degrees*/343));
 #endif
 
-    wxMenu* helpmenu = new wxMenu;
-    helpmenu->Append(wxID_ABOUT);
-
     wxMenuBar* menubar = new wxMenuBar();
     menubar->Append(filemenu, wmsg(/*&File*/210));
     menubar->Append(rotmenu, wmsg(/*&Rotation*/211));
@@ -839,6 +836,9 @@ void MainFrm::CreateMenuBar()
 #ifndef __WXMAC__
     // On wxMac the "About" menu item will be moved elsewhere, so we suppress
     // this menu since it will then be empty.
+    wxMenu* helpmenu = new wxMenu;
+    helpmenu->Append(wxID_ABOUT);
+
     menubar->Append(helpmenu, wmsg(/*&Help*/215));
 #endif
     SetMenuBar(menubar);
@@ -910,7 +910,7 @@ void MainFrm::CreateSidePanel()
     m_Tree = new AvenTreeCtrl(this, panel);
 
 //    m_RegexpCheckBox = new wxCheckBox(find_panel, -1,
-//				      msg(/*Regular expression*/334));
+//				      msg(/*Regular expression*/));
 
     wxBoxSizer *panel_sizer = new wxBoxSizer(wxVERTICAL);
     panel_sizer->Add(m_Tree, 1, wxALL | wxEXPAND, 2);
@@ -1162,7 +1162,7 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
 		if (i == m_Labels.end()) {
 		    // Unattached cross-section - ignore for now.
 		    printf("unattached cross-section\n");
-		    if (current_tube->size() == 1)
+		    if (current_tube->size() <= 1)
 			tubes.resize(tubes.size() - 1);
 		    current_tube = NULL;
 		    break;
@@ -1184,7 +1184,7 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
 		// If there's only one cross-section in the tube, just
 		// discard it for now.  FIXME: we should handle this
 		// when we come to skinning the tubes.
-		if (current_tube && current_tube->size() == 1)
+		if (current_tube && current_tube->size() <= 1)
 		    tubes.resize(tubes.size() - 1);
 		current_tube = NULL;
 		break;
@@ -1254,7 +1254,7 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
     // If there's only one cross-section in the tube, just
     // discard it for now.  FIXME: we should handle this
     // when we come to skinning the tubes.
-    if (current_tube && current_tube->size() == 1)
+    if (current_tube && current_tube->size() <= 1)
 	tubes.resize(tubes.size() - 1);
 
     separator = survey->separator;
@@ -1264,7 +1264,7 @@ bool MainFrm::LoadData(const wxString& file, wxString prefix)
 
     // Check we've actually loaded some legs or stations!
     if (!m_HasUndergroundLegs && !m_HasSurfaceLegs && m_Labels.empty()) {
-	wxString m = wxString::Format(wmsg(/*No survey data in 3d file `%s'*/202), file.c_str());
+	wxString m = wxString::Format(wmsg(/*No survey data in 3d file “%s”*/202), file.c_str());
 	wxGetApp().ReportError(m);
 	return false;
     }
@@ -1496,7 +1496,7 @@ void MainFrm::FillTree()
 	// Set the colour for an item in the survey tree.
 	if (label->IsEntrance()) {
 	    // Entrances are green (like entrance blobs).
-	    m_Tree->SetItemTextColour(id, wxColour(0, 255, 0));
+	    m_Tree->SetItemTextColour(id, wxColour(0, 255, 40));
 	} else if (label->IsSurface()) {
 	    // Surface stations are dark green.
 	    m_Tree->SetItemTextColour(id, wxColour(49, 158, 79));
@@ -1739,7 +1739,7 @@ void MainFrm::OnScreenshot(wxCommandEvent&)
 	    png_handled = true;
 	}
 	if (!m_Gfx->SaveScreenshot(dlg.GetPath(), wxBITMAP_TYPE_PNG)) {
-	    wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file `%s'*/110), dlg.GetPath().c_str()));
+	    wxGetApp().ReportError(wxString::Format(wmsg(/*Error writing to file “%s”*/110), dlg.GetPath().c_str()));
 	}
     }
 }
