@@ -3,7 +3,7 @@
 //
 //  Class for writing movies from Aven.
 //
-//  Copyright (C) 2004,2010 Olly Betts
+//  Copyright (C) 2004,2010,2011 Olly Betts
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@ struct AVFormatContext;
 struct AVStream;
 struct AVFrame;
 struct AVPicture;
+struct SwsContext;
 
 class MovieMaker {
     AVFormatContext *oc;
@@ -31,9 +32,10 @@ class MovieMaker {
     int out_size;
     AVFrame *frame;
     unsigned char *outbuf;
-    AVPicture *in;
     AVPicture *out;
     unsigned char *pixels;
+    SwsContext *sws_ctx;
+    int averrno;
  
 public:
     MovieMaker();
@@ -43,4 +45,5 @@ public:
     int GetHeight() const;
     void AddFrame();
     ~MovieMaker();
+    const char * get_error_string() const;
 };
